@@ -35,8 +35,8 @@ Usage::
     search_insights_paginator: SearchInsightsPaginator = client.get_paginator("search_insights")
     ```
 """
-from mypy_boto3_devops_guru.client import DevopsGuruClient
-from mypy_boto3_devops_guru.paginator import (
+from .client import DevopsGuruClient
+from .paginator import (
     DescribeResourceCollectionHealthPaginator,
     GetCostEstimationPaginator,
     GetResourceCollectionPaginator,
