@@ -23,9 +23,12 @@ __all__ = (
     "AnomalySeverity",
     "AnomalyStatus",
     "CloudWatchMetricsStat",
+    "CostEstimationServiceResourceState",
+    "CostEstimationStatus",
     "DescribeResourceCollectionHealthPaginatorName",
     "EventClass",
     "EventDataSource",
+    "GetCostEstimationPaginatorName",
     "GetResourceCollectionPaginatorName",
     "InsightFeedbackOption",
     "InsightSeverity",
@@ -36,9 +39,11 @@ __all__ = (
     "ListInsightsPaginatorName",
     "ListNotificationChannelsPaginatorName",
     "ListRecommendationsPaginatorName",
+    "Locale",
     "OptInStatus",
     "ResourceCollectionType",
     "SearchInsightsPaginatorName",
+    "ServiceName",
     "UpdateResourceCollectionAction",
 )
 
@@ -48,11 +53,14 @@ AnomalyStatus = Literal["CLOSED", "ONGOING"]
 CloudWatchMetricsStat = Literal[
     "Average", "Maximum", "Minimum", "SampleCount", "Sum", "p50", "p90", "p99"
 ]
+CostEstimationServiceResourceState = Literal["ACTIVE", "INACTIVE"]
+CostEstimationStatus = Literal["COMPLETED", "ONGOING"]
 DescribeResourceCollectionHealthPaginatorName = Literal["describe_resource_collection_health"]
 EventClass = Literal[
     "CONFIG_CHANGE", "DEPLOYMENT", "INFRASTRUCTURE", "SCHEMA_CHANGE", "SECURITY_CHANGE"
 ]
 EventDataSource = Literal["AWS_CLOUD_TRAIL", "AWS_CODE_DEPLOY"]
+GetCostEstimationPaginatorName = Literal["get_cost_estimation"]
 GetResourceCollectionPaginatorName = Literal["get_resource_collection"]
 InsightFeedbackOption = Literal[
     "ALERT_TOO_SENSITIVE",
@@ -69,7 +77,47 @@ ListEventsPaginatorName = Literal["list_events"]
 ListInsightsPaginatorName = Literal["list_insights"]
 ListNotificationChannelsPaginatorName = Literal["list_notification_channels"]
 ListRecommendationsPaginatorName = Literal["list_recommendations"]
+Locale = Literal[
+    "DE_DE",
+    "EN_GB",
+    "EN_US",
+    "ES_ES",
+    "FR_FR",
+    "IT_IT",
+    "JA_JP",
+    "KO_KR",
+    "PT_BR",
+    "ZH_CN",
+    "ZH_TW",
+]
 OptInStatus = Literal["DISABLED", "ENABLED"]
-ResourceCollectionType = Literal["AWS_CLOUD_FORMATION"]
+ResourceCollectionType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE"]
 SearchInsightsPaginatorName = Literal["search_insights"]
+ServiceName = Literal[
+    "API_GATEWAY",
+    "APPLICATION_ELB",
+    "AUTO_SCALING_GROUP",
+    "CLOUD_FRONT",
+    "DYNAMO_DB",
+    "EC2",
+    "ECS",
+    "EKS",
+    "ELASTIC_BEANSTALK",
+    "ELASTI_CACHE",
+    "ELB",
+    "ES",
+    "KINESIS",
+    "LAMBDA",
+    "NAT_GATEWAY",
+    "NETWORK_ELB",
+    "RDS",
+    "REDSHIFT",
+    "ROUTE_53",
+    "S3",
+    "SAGE_MAKER",
+    "SNS",
+    "SQS",
+    "STEP_FUNCTIONS",
+    "SWF",
+]
 UpdateResourceCollectionAction = Literal["ADD", "REMOVE"]
